@@ -421,20 +421,18 @@ class BaseExperiment:
 
         elif isinstance(self.model, pl.LightningModule): # other lightning modules not in astrape
             batch_size = 256 if torch.cuda.is_available() else 64
-            
             data_module = initialize_datamodule(
-                batch_size=batch_size, 
-                X=self.X, 
-                y=self.y,
-                X_val=self.X_val.reshape(-1, *(self.X.shape[1:])),
-                y_val=self.y_val,
-                X_test=self.X_test.reshape(-1, *(self.X.shape[1:])),
-                y_test=self.y_test,
-                test_size=self.test_size,
-                random_state=self.random_state,
-                stratify=self.stratify
-            )
-            
+                    batch_size=batch_size, 
+                    X=self.X, 
+                    y=self.y,
+                    X_val=self.X_val,
+                    y_val=self.y_val,
+                    X_test=self.X_test,
+                    y_test=self.y_test,
+                    test_size=self.test_size,
+                    random_state=self.random_state,
+                    stratify=self.stratify
+                )
             
         elif isinstance(self.model, BaseEstimator):
             if self.X_test is None and self.y_test is None:
