@@ -12,7 +12,8 @@ from astrape.constants.astrape_constants import *
 from astrape.exceptions.exceptions import *
 import logging
 
-from benchay.codes.astrape_pkg.astrape.base.model_base import BaseNet
+from astrape.base.model_base import BaseNet
+
 log = logging.getLogger()
 log.setLevel(logging.INFO)
 
